@@ -6,11 +6,11 @@ Module contains classes presenting Element and Specie (Element + oxidation state
 
 __author__="Shyue Ping Ong, Michael Kocher"
 __copyright__ = "Copyright 2011, The Materials Project"
-__version__ = "1.0"
+__version__ = "1.1"
 __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __status__ = "Production"
-__date__ ="$Sep 23, 2011M$"
+__date__ ="Sep 23, 2011"
 
 import os
 import re
@@ -101,12 +101,26 @@ class Element(object):
     @property
     def max_oxidation_state(self):
         """Maximum oxidation state for element"""
-        return self._data['Max oxidation state']
+        if 'Oxidation states' in self._data:
+            return max(self._data['Oxidation states'])
+        return 0
     
     @property
     def min_oxidation_state(self):
         """Minimum oxidation state for element"""
-        return self._data['Min oxidation state']
+        if 'Oxidation states' in self._data:
+            return min(self._data['Oxidation states'])
+        return 0
+    
+    @property
+    def oxidation_states(self):
+        """Tuple of all known oxidation states"""
+        return tuple(self._data.get('Oxidation states', list()))
+    
+    @property
+    def common_oxidation_states(self):
+        """Tuple of all known oxidation states"""
+        return tuple(self._data.get('Common oxidation states', list()))
     
     @property
     def mendeleev_no(self):
