@@ -11,15 +11,28 @@ __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyue@mit.edu"
 __date__ = "Nov 12, 2011"
 
-import sys
 import itertools
+import argparse
+
 from pymatgen.io.vaspio import Incar
 from pymatgen.util.string_utils import str_aligned
 
-filepath1 = sys.argv[1]
-filepath2 = sys.argv[2]
+
+parser = argparse.ArgumentParser(description='''Convenient INCAR diff. 
+Author: Shyue Ping Ong
+Version: 1.0
+Last updated: Oct 26 2011''')
+parser.add_argument('incar_file', metavar='filename', type=str, nargs = 2, help='files to process')
+
+args = parser.parse_args()
+
+filepath1 = args.incar_file[0]
+filepath2 = args.incar_file[1]
 incar1 = Incar.from_file(filepath1)
-incar2 = Incar.from_file(filepath2)        
+incar2 = Incar.from_file(filepath2)
+
+print type(incar1['EDIFF'])
+print type(incar2['EDIFF'])
 
 def format_lists(v):
     if isinstance(v, (tuple, list)):
